@@ -2,15 +2,20 @@ from .activations import identity, sigmoid_beta, swish_beta
 from .competitions import wtac
 from .distances import (euclidean_distance, lomega_distance, lpnorm_distance,
                         omega_distance, squared_euclidean_distance)
+from .losses import glvq_loss
+from .normalization import nullspace_normalization, trace_normalization
 
 __all__ = [
     "euclidean_distance",
+    "glvq_loss",
     "identity",
     "lomega_distance",
     "lpnorm_distance",
+    "nullspace_normalization",
     "omega_distance",
     "sigmoid_beta",
     "squared_euclidean_distance",
     "swish_beta",
+    "trace_normalization",
     "wtac",
 ]
